Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(136)

Unified Diff: src/compiler/schedule.h

Issue 805263003: [turbofan] move assembly order to InstructionBlock (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/instruction-selector.cc ('k') | src/compiler/schedule.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/schedule.h
diff --git a/src/compiler/schedule.h b/src/compiler/schedule.h
index 8c3e29a45a784a6541ce2ce6759094221a91cbce..0bba689785728fe9409bdc7fd8edca499cfda020 100644
--- a/src/compiler/schedule.h
+++ b/src/compiler/schedule.h
@@ -163,9 +163,8 @@ class BasicBlock FINAL : public ZoneObject {
int32_t loop_depth() const { return loop_depth_; }
void set_loop_depth(int32_t loop_depth);
- RpoNumber GetAoNumber() const { return RpoNumber::FromInt(ao_number_); }
- int32_t ao_number() const { return ao_number_; }
- void set_ao_number(int32_t ao_number) { ao_number_ = ao_number; }
+ int32_t loop_number() const { return loop_number_; }
+ void set_loop_number(int32_t loop_number) { loop_number_ = loop_number; }
RpoNumber GetRpoNumber() const { return RpoNumber::FromInt(rpo_number_); }
int32_t rpo_number() const { return rpo_number_; }
@@ -176,7 +175,7 @@ class BasicBlock FINAL : public ZoneObject {
bool LoopContains(BasicBlock* block) const;
private:
- int32_t ao_number_; // assembly order number of the block.
+ int32_t loop_number_; // loop number of the block.
int32_t rpo_number_; // special RPO number of the block.
bool deferred_; // true if the block contains deferred code.
int32_t dominator_depth_; // Depth within the dominator tree.
« no previous file with comments | « src/compiler/instruction-selector.cc ('k') | src/compiler/schedule.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698